@@ -53,7 +53,7 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
-                print(f"Config {cfg_file} found at path { file }")
+                print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
         # else:
             # print(f"Config file not found in {cfg_file} directory.")
